@@ -175,13 +175,21 @@ has bin => (
 
 =pod
 
-=head2 is_infinite
+=head2 time_zone
 
-An boolean defining if the interaction loop should be infinite or not.
+Required attribute.
+
+A string representing the time zone to be considered for all date/time values recovered from C<srvrmgr>.
+
+See L<DateTime::TimeZone> C<all_names> methods to list the available time zones that you can use. The on-liner
+below show do it for you to find a proper value:
+
+    perl -MDateTime::TimeZone -e 'foreach ( DateTime::TimeZone->all_names ) { print "$_\n" }'
 
 =cut
 
-has is_infinite => ( isa => 'Bool', is => 'ro', default => sub { 0 } );
+has time_zone =>
+  ( isa => 'Str', is => 'ro', required => 1, reader => 'get_time_zone' );
 
 =pod
 
@@ -371,6 +379,10 @@ has cmd_stack => (
 
 =head1 METHODS
 
+=head2 get_time_zone
+
+Returns the content of the attribute C<time_zone>.
+
 =head2 get_cmd_stack
 
 Returns the content of the attribute C<cmd_stack>.
@@ -479,10 +491,6 @@ Sets the content of the C<bin> attribute. Expects a string as parameter.
 
 Returns the content of C<pid> attribute as an integer.
 
-=head2 is_infinite
-
-Returns the content of the attribute C<is_infinite>, returning true or false depending on this value.
-
 =head2 BUILD
 
 L<Moose> BUILD method is used by this class to install signal handlers for the following signals:
@@ -507,9 +515,12 @@ ALRM
 
 sub BUILD {
 
-	$SIG{INT}  = sub { $SIG_INT   = 1 };
-	$SIG{PIPE} = sub { $SIG_PIPE  = 1 };
-	$SIG{ALRM} = sub { $SIG_ALARM = 1 };
+    my $self = shift;
+
+    $SIG{INT}  = sub { $SIG_INT   = 1 };
+    $SIG{PIPE} = sub { $SIG_PIPE  = 1 };
+    $SIG{ALRM} = sub { $SIG_ALARM = 1 };
+    $ENV{SIEBEL_TZ} = $self->get_time_zone();
 
 }
 
@@ -745,7 +756,7 @@ sub get_lock_file {
 
     my $self = shift;
 
-    my $filename = $self->blessed;
+    my $filename = $self->blessed();
     $filename =~ s/\:{2}/_/g;
 
     return File::Spec->catfile( $self->get_lock_dir, ( $filename . '.lock' ) );
@@ -765,74 +776,76 @@ our $siebel_error = SIEBEL_ERROR;
 # if no critical error was detected
 sub _check_error {
 
-    my $self    = shift;
-    my $content = shift;
-	my $is_error = shift; #boolean
+    my $self     = shift;
+    my $content  = shift;
+    my $is_error = shift;    #boolean
 
-	my $logger = Siebel::Srvrmgr->gimme_logger( ref($self) );
+    my $logger = Siebel::Srvrmgr->gimme_logger( $self->blessed() );
 
-	# :WORKAROUND: to enable the code to process both scalar and array reference data
-	# without duplicating code
-	
-	unless ( ref( $content ) eq 'ARRAY' ) {
+# :WORKAROUND: to enable the code to process both scalar and array reference data
+# without duplicating code
 
-		my $temp = $content;
-		$content = [ $temp ];
+    unless ( ref($content) eq 'ARRAY' ) {
 
-	}
+        my $temp = $content;
+        $content = [$temp];
 
-	foreach my $line ( @{$content} ) {
+    }
 
-		if ( $line =~ $siebel_error ) {
+    foreach my $line ( @{$content} ) {
 
-		  SWITCH: {
+        if ( $line =~ $siebel_error ) {
 
-				if ( $line =~ $adm_60070 ) {
+          SWITCH: {
 
-					if ( $logger->is_warn() ) {
-					
-						$logger->warn("Found [$line]. Trying to get additional information from next line");
-						return 1;
-						
-					}
-				}
+                if ( $line =~ $adm_60070 ) {
 
-				if ( $line =~ $adm_02043 ) {
-					$logger->logdie('Could not find the Siebel Server');
-				}
+                    if ( $logger->is_warn() ) {
 
-				if ( $line =~ $adm_02071 ) {
-					$logger->logdie('Could not find the Siebel Enterprise');
-				}
+                        $logger->warn(
+"Found [$line]. Trying to get additional information from next line"
+                        );
+                        return 1;
 
-				if ( $line =~ $adm_02049 ) {
-					$logger->logdie('Generic error');
-				}
+                    }
+                }
 
-				if ( $line =~ $adm_02751 ) {
-					$logger->logdie('Unable to open file');
-				}
-				else {
-					$logger->logdie(
-						"Unknown error [$line], aborting execution");
-				}
+                if ( $line =~ $adm_02043 ) {
+                    $logger->logdie('Could not find the Siebel Server');
+                }
 
-			}
+                if ( $line =~ $adm_02071 ) {
+                    $logger->logdie('Could not find the Siebel Enterprise');
+                }
 
-		}
-		else {
+                if ( $line =~ $adm_02049 ) {
+                    $logger->logdie('Generic error');
+                }
 
-			$logger->debug(
+                if ( $line =~ $adm_02751 ) {
+                    $logger->logdie('Unable to open file');
+                }
+                else {
+                    $logger->logdie(
+                        "Unknown error [$line], aborting execution");
+                }
+
+            }
+
+        }
+        else {
+
+            $logger->debug(
 "Got $line. Since it doesn't look like a Siebel error, I will try to keep running"
-			) if ( $logger->is_debug );
-			
-			$logger->warn($line) if ( $logger->is_warn() and $is_error );
+            ) if ( $logger->is_debug );
 
-			return 1;
+            $logger->warn($line) if ( $logger->is_warn() and $is_error );
 
-		}
+            return 1;
 
-	}
+        }
+
+    }
 
 }
 
@@ -852,7 +865,7 @@ sub DEMOLISH {
 
     my $self = shift;
 
-    my $logger = Siebel::Srvrmgr->gimme_logger( ref($self) );
+    my $logger = Siebel::Srvrmgr->gimme_logger( $self->blessed() );
 
     $logger->info('Terminating daemon: preparing cleanup');
 
@@ -878,8 +891,8 @@ sub DEMOLISH {
     }
 
     $logger->info( ref($self) . ' says bye-bye' ) if ( $logger->is_info() );
-	
-	Log::Log4perl->remove_logger($logger);
+
+    Log::Log4perl->remove_logger($logger);
 
 }
 
@@ -903,8 +916,7 @@ sub _create_lock {
 
     my $self = shift;
 
-    my $logger = Siebel::Srvrmgr->gimme_logger( ref($self) );
-    weaken($logger);
+    my $logger = Siebel::Srvrmgr->gimme_logger( $self->blessed() );
 
     my $lock_file = $self->get_lock_file;
 
@@ -940,8 +952,8 @@ sub _del_lock {
 
     my $self      = shift;
     my $lock_file = $self->get_lock_file;
-	
-    my $logger = Siebel::Srvrmgr->gimme_logger( ref($self) );
+
+    my $logger = Siebel::Srvrmgr->gimme_logger( $self->blessed() );
 
     if ( -e $lock_file ) {
 
@@ -966,64 +978,66 @@ sub _my_cleanup {
 
 sub _define_lock_dir {
 
-	my $lock_dir = undef;
-	
-	CASE: {
+    my $lock_dir = undef;
 
-		if ( $Config{osname} =~ /^linux$/i ) {
+  CASE: {
 
-			$lock_dir = $ENV{HOME};
-			last CASE;
+        if ( $Config{osname} =~ /^linux$/i ) {
 
-		}
+            $lock_dir = $ENV{HOME};
+            last CASE;
 
-		if ( $Config{osname} =~ /^aix$/i ) {
+        }
 
-			$lock_dir = $ENV{HOME};
-			last CASE;
+        if ( $Config{osname} =~ /^aix$/i ) {
 
-		}
+            $lock_dir = $ENV{HOME};
+            last CASE;
 
-		if ( $Config{osname} =~ /^hpux$/i ) {
+        }
 
-			$lock_dir = $ENV{HOME};
-			last CASE;
+        if ( $Config{osname} =~ /^hpux$/i ) {
 
-		}
+            $lock_dir = $ENV{HOME};
+            last CASE;
 
-		if ( $Config{osname} =~ /^mswin32$/i ) {
+        }
 
-			if (defined( $ENV{HOMEDIR} ) ) {
-			
-				$lock_dir = $ENV{HOMEDIR};
-			
-			} else {
-			
-				$lock_dir = $ENV{USERPROFILE};
-			
-			}
-			
-			last CASE;
+        if ( $Config{osname} =~ /^mswin32$/i ) {
 
-		}
+            if ( defined( $ENV{HOMEDIR} ) ) {
 
-		if ( $Config{osname} =~ /^solaris$/i ) {
+                $lock_dir = $ENV{HOMEDIR};
 
-			$lock_dir = $ENV{HOME};
-			last CASE;
+            }
+            else {
 
-		}
-		else {
+                $lock_dir = $ENV{USERPROFILE};
 
-			confess "don't know what to do with $Config{osname}";
+            }
 
-		}
-	
-	}
-	
-	confess "could not defined a lock_dir for $Config{osname}" unless(defined($lock_dir));
-	
-	return $lock_dir;
+            last CASE;
+
+        }
+
+        if ( $Config{osname} =~ /^solaris$/i ) {
+
+            $lock_dir = $ENV{HOME};
+            last CASE;
+
+        }
+        else {
+
+            confess "don't know what to do with $Config{osname}";
+
+        }
+
+    }
+
+    confess "could not defined a lock_dir for $Config{osname}"
+      unless ( defined($lock_dir) );
+
+    return $lock_dir;
 
 }
 
