@@ -11,8 +11,8 @@ Siebel::Srvrmgr::Daemon::Action::Check::Component - role for classes that hold S
 
 =head1 DESCRIPTION
 
-This class is intended to be used by classes that provides information
-about which components are available in a Siebel server and which is their expected status.
+This Moose Role is intended to be used by classes that provides information about which components are available in 
+a Siebel server and which is their expected status.
 
 =head1 ATTRIBUTES
 
@@ -59,7 +59,9 @@ has componentGroup => (
 
 =head2 OKStatus
 
-The status that the component is expected to have. It may be one, several (concatenated with a pipe character) or none.
+The status that the component is expected to have. It may be one or several (concatenated with a pipe character).
+
+This attribute is required during object creation.
 
 =cut
 
@@ -74,7 +76,9 @@ has OKStatus => (
 
 =head2 taskOKStatus
 
-The expected tasks status of the component. It may be one,  several (concatenated with a pipe character) or none.
+The expected tasks status of the component. It may be one or several (concatenated with a pipe character).
+
+This attribute is required during object creation.
 
 =cut
 
@@ -82,13 +86,15 @@ has taskOKStatus => (
     isa    => 'NotNullStr',
     is     => 'ro',
     reader => 'get_taskOKStatus',
+    required => 1
 );
 
 =pod
 
 =head2 criticality
 
-A integer indicating how critical it is if the component does not have the expected status: the largest the number, the more critical it is.
+A integer indicating how critical it is if the component does not have the expected status: the largest the number, 
+the more critical it is.
 
 =cut
 
@@ -111,10 +117,6 @@ All attributes have their respective getter as C<get_><attribute name>.
 
 =item *
 
-L<Siebel::Srvrmgr::Daemon::Action::CheckComps>
-
-=item *
-
 L<Siebel::Srvrmgr::Daemon::Action::Check::Server>
 
 =back
