@@ -26,8 +26,6 @@ L<Siebel::Srvrmgr::Daemon::Action>) and an optional parameter in the form of an
 
 =cut
 
-use warnings;
-use strict;
 use Moose;
 use MooseX::FollowPBP;
 use namespace::autoclean;
@@ -55,7 +53,7 @@ The action parameter expects a string with the name of a subclass of L<Siebel::S
 used (for example, 'Foobar' will produce an instance of a 'Siebel::Srvrmgr::Daemon::Action' subclass, if it exists). If another class is used, then the complete name
 of the class must be used.
 
-Beware that the class passed as parameter must be able to deal with the srvrmgr and do something about it.
+Beware that the class passed as parameter must be able to deal with the srvrmgr output and do something with it.
 
 This attribute is obligatory.
 
@@ -74,7 +72,8 @@ Since this parameter is optional, if some value is passed by a subclass that doe
 
 =cut
 
-has params => ( isa => 'ArrayRef', is => 'ro', required => 0 );
+has params =>
+  ( isa => 'ArrayRef', is => 'ro', required => 0, default => sub { [] } );
 
 =pod
 
@@ -89,7 +88,7 @@ value.
 
 =head1 SEE ALSO
 
-=over 2
+=over
 
 =item *
 
@@ -107,11 +106,11 @@ L<Siebel::Srvrmgr::Daemon> command attribute description.
 
 =head1 AUTHOR
 
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>.
 
 This file is part of Siebel Monitoring Tools.
 
@@ -126,7 +125,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with Siebel Monitoring Tools.  If not, see <http://www.gnu.org/licenses/>.
+along with Siebel Monitoring Tools.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
 
