@@ -68,12 +68,7 @@ sub new {
     my $class   = shift;
     my $map_ref = shift;
 
-    my $log_cfg = Siebel::Srvrmgr->logging_cfg();
-
-    die 'Could not start logging facilities'
-      unless ( Log::Log4perl->init_once( \$log_cfg ) );
-
-    my $logger = Log::Log4perl->get_logger('Siebel::Srvrmgr::ListParser');
+    my $logger = Siebel::Srvrmgr->gimme_logger('Siebel::Srvrmgr::ListParser');
 
     $logger->logdie('the output type mapping reference received is not valid')
       unless ( ( defined($map_ref) ) and ( ref($map_ref) eq 'HASH' ) );
@@ -83,9 +78,7 @@ sub new {
 
             my $self = shift;
 
-            my $curr_line = shift( @{ $self->notes('all_data') } );
- # :TODO:22-02-2015 18:22:29:: add a new method to do that
-            $self->notes( 'line_num' => ( $self->notes('line_num') + 1 ) );
+            my $curr_line = shift( @{ $self->{data} } );
 
             if ( defined($curr_line) ) {
 
@@ -98,13 +91,13 @@ sub new {
                 }
                 else {
 
-                    $self->notes( line => $curr_line );
+                    $self->{curr_line} = $curr_line;
                     return 0;
 
                 }
 
             }
-            else { # no more lines to process
+            else {    # no more lines to process
 
                 return 1;
 
@@ -119,7 +112,7 @@ sub new {
             do => sub {
 
                 my $logger =
-                  Log::Log4perl->get_logger('Siebel::Srvrmgr::ListParser');
+                  Siebel::Srvrmgr->gimme_logger('Siebel::Srvrmgr::ListParser');
 
                 if ( $logger->is_debug() ) {
 
@@ -133,10 +126,11 @@ sub new {
 
                     my $state = shift;
 
-                    if ( defined( $state->notes('line') ) ) {
+                    my $line = $state->machine()->{curr_line};
 
-                        return (
-                            $state->notes('line') =~ $map_ref->{greetings} );
+                    if ( defined($line) ) {
+
+                        return ( $line =~ $map_ref->{greetings} );
 
                     }
                     else {
@@ -149,10 +143,11 @@ sub new {
                 command_submission => sub {
 
                     my $state = shift;
+                    my $line  = $state->machine()->{curr_line};
 
-                    if ( defined( $state->notes('line') ) ) {
+                    if ( defined($line) ) {
 
-                        return ( $state->notes('line') =~ SRVRMGR_PROMPT );
+                        return ( $line =~ SRVRMGR_PROMPT );
 
                     }
                     else {
@@ -186,7 +181,8 @@ sub new {
                 command_submission => sub {
 
                     my $state = shift;
-                    return ( $state->notes('line') =~ SRVRMGR_PROMPT );
+                    my $line  = $state->machine()->{curr_line};
+                    return ( $line =~ SRVRMGR_PROMPT );
 
                 },
             ],
@@ -196,7 +192,7 @@ sub new {
             do => sub {
 
                 my $logger =
-                  Log::Log4perl->get_logger('Siebel::Srvrmgr::ListParser');
+                  Siebel::Srvrmgr->gimme_logger('Siebel::Srvrmgr::ListParser');
                 $logger->debug('Enterprise says bye-bye');
 
             },
@@ -224,7 +220,7 @@ sub new {
                 command_submission => sub {
 
                     my $state = shift;
-                    return ( $state->notes('line') =~ SRVRMGR_PROMPT );
+                    return ( $state->machine->{curr_line} =~ SRVRMGR_PROMPT );
 
                 },
             ],
@@ -247,7 +243,7 @@ sub new {
                 command_submission => sub {
 
                     my $state = shift;
-                    return ( $state->notes('line') =~ SRVRMGR_PROMPT );
+                    return ( $state->machine->{curr_line} =~ SRVRMGR_PROMPT );
 
                 },
             ],
@@ -270,7 +266,7 @@ sub new {
                 command_submission => sub {
 
                     my $state = shift;
-                    return ( $state->notes('line') =~ SRVRMGR_PROMPT );
+                    return ( $state->machine->{curr_line} =~ SRVRMGR_PROMPT );
 
                 },
             ],
@@ -293,7 +289,7 @@ sub new {
                 command_submission => sub {
 
                     my $state = shift;
-                    return ( $state->notes('line') =~ SRVRMGR_PROMPT );
+                    return ( $state->machine->{curr_line} =~ SRVRMGR_PROMPT );
 
                 },
             ],
@@ -316,7 +312,7 @@ sub new {
                 command_submission => sub {
 
                     my $state = shift;
-                    return ( $state->notes('line') =~ SRVRMGR_PROMPT );
+                    return ( $state->machine->{curr_line} =~ SRVRMGR_PROMPT );
 
                 },
             ],
@@ -339,7 +335,7 @@ sub new {
                 command_submission => sub {
 
                     my $state = shift;
-                    return ( $state->notes('line') =~ SRVRMGR_PROMPT );
+                    return ( $state->machine->{curr_line} =~ SRVRMGR_PROMPT );
 
                 },
             ],
@@ -362,7 +358,7 @@ sub new {
                 command_submission => sub {
 
                     my $state = shift;
-                    return ( $state->notes('line') =~ SRVRMGR_PROMPT );
+                    return ( $state->machine->{curr_line} =~ SRVRMGR_PROMPT );
 
                 },
             ],
@@ -385,7 +381,7 @@ sub new {
                 command_submission => sub {
 
                     my $state = shift;
-                    return ( $state->notes('line') =~ SRVRMGR_PROMPT );
+                    return ( $state->machine->{curr_line} =~ SRVRMGR_PROMPT );
 
                 },
             ],
@@ -408,7 +404,7 @@ sub new {
                 command_submission => sub {
 
                     my $state = shift;
-                    return ( $state->notes('line') =~ SRVRMGR_PROMPT );
+                    return ( $state->machine->{curr_line} =~ SRVRMGR_PROMPT );
 
                 },
             ],
@@ -420,7 +416,7 @@ sub new {
                 my $state = shift;
 
                 my $logger =
-                  Log::Log4perl->get_logger('Siebel::Srvrmgr::ListParser');
+                  Siebel::Srvrmgr->gimme_logger('Siebel::Srvrmgr::ListParser');
                 if ( $logger->is_debug() ) {
 
                     $logger->debug( 'command_submission got ['
@@ -430,7 +426,7 @@ sub new {
                 }
 
                 $state->notes( found_prompt => 1 );
-                my $cmd = ( $state->notes('line') =~ SRVRMGR_PROMPT )[1];
+                my $cmd = ( $state->machine->{curr_line} =~ SRVRMGR_PROMPT )[1];
 
                 if ( ( defined($cmd) ) and ( $cmd ne '' ) ) {
 
@@ -449,9 +445,7 @@ sub new {
 
                     if ( $logger->is_debug() ) {
 
-                        $logger->debug(
-                            'got prompt, but no command submitted in line '
-                              . $state->notes('line_num') );
+                        $logger->debug('got prompt, but no command submitted');
 
                     }
 
@@ -640,16 +634,45 @@ sub new {
                     }
 
                 },
+
                 # add other possibilities here of list commands
             ],
             message => 'command submitted'
         }
     );
 
+    $self->{data}      = undef;
+    $self->{curr_line} = undef;
+
     return $self;
 
 }
 
+=head2 set_data
+
+Set the array reference of the data to be parsed by this object.
+
+=cut
+
+sub set_data {
+
+    my $self = shift;
+    $self->{data} = shift;
+
+}
+
+=head2 get_curr_line
+
+Returns a string, the current line being processed by this object.
+
+=cut
+
+sub get_curr_line {
+
+    return shift->{curr_line};
+
+}
+
 1;
 
 =pod
