@@ -1,6 +1,7 @@
 package Siebel::Srvrmgr::ListParser::Output::Tabular::ListServers;
 use Moose;
 use namespace::autoclean;
+use Siebel::Srvrmgr::ListParser::Output::ListServers::Server;
 
 =pod
 
@@ -46,18 +47,20 @@ All from parent class.
 
 All methods from superclass plus some additional ones described below.
 
+=head2 get_data_parsed
+
 The hash reference returned by C<get_data_parsed> will look like that:
 
 	siebfoobar' => HASH
-	  'end_time' => ''
-	  'host_name' => 'siebfoobar'
-	  'install_dir' => '/app/siebel/siebsrvr'
-	  'sblmgr_pid' => 20452
-	  'sblsrvr_group_name' => ''
-	  'sblsrvr_state' => 'Running'
-	  'sblsrvr_status' => '8.1.1.7 [21238] LANG_INDEPENDENT'
-	  'start_time' => '2013-04-22 15:32:25'
-	  'sv_disp_state' => 'Running'
+	  'END_TIME' => ''
+	  'HOST_NAME' => 'siebfoobar'
+	  'INSTALL_DIR' => '/app/siebel/siebsrvr'
+	  'SBLMGR_PID' => 20452
+	  'SBLSRVR_GROUP_NAME' => ''
+	  'SBLSRVR_STATE' => 'Running'
+	  'SBLSRVR_STATUS' => '8.1.1.7 [21238] LANG_INDEPENDENT'
+	  'START_TIME' => '2013-04-22 15:32:25'
+	  'SV_DISP_STATE' => 'Running'
 
 where the keys are the Siebel servers names, each one holding a reference to another hash with the keys shown above.
 
@@ -79,27 +82,62 @@ sub _build_expected {
 
 }
 
-=pod
+=head2 get_servers
 
-=head2 get_lc_fields
+Returns a iterator in a form of a sub reference.
 
-Returns an array reference with all the expected fields names in lowercase.
+Which dereference of anonymous sub reference will return a L<Siebel::Srvrmgr::ListParser::Output::ListServers::Server> object
+until the list of servers is exausted. In this case the sub reference will return C<undef>.
 
 =cut
 
-sub get_lc_fields {
+sub get_servers {
 
-    my $self = shift;
-    my @names;
+    my $self    = shift;
+    my $counter = 0;
 
-    foreach ( @{ $self->get_expected_fields() } ) {
+    my $servers_ref = $self->get_data_parsed;
 
-        push( @names, lc($_) );
+    my @servers = sort( keys( %{$servers_ref} ) );
+    my $total   = scalar(@servers) - 1;
 
-    }
+    return sub {
 
-    return \@names;
+        if ( $counter <= $total ) {
 
+            my $server_ref = $servers_ref->{ $servers[$counter] };
+            $counter++;
+
+            my %attribs = (
+                name           => $server_ref->{SBLSRVR_NAME},
+                group          => $server_ref->{SBLSRVR_GROUP_NAME},
+                host           => $server_ref->{HOST_NAME},
+                install_dir    => $server_ref->{INSTALL_DIR},
+                disp_state     => $server_ref->{SV_DISP_STATE},
+                state          => $server_ref->{SBLSRVR_STATE},
+                start_datetime => $server_ref->{START_TIME},
+                end_datetime   => $server_ref->{END_TIME},
+                status         => $server_ref->{SBLSRVR_STATUS}
+            );
+
+            # the server can be stopped, so no PID associated with it
+            if ( defined( $server_ref->{SBLMGR_PID} ) ) {
+
+                $attribs{pid} = $server_ref->{SBLMGR_PID};
+
+            }
+
+            return Siebel::Srvrmgr::ListParser::Output::ListServers::Server
+              ->new( \%attribs );
+
+        }
+        else {
+
+            return undef;
+
+        }
+
+      }    # end of sub block
 }
 
 sub _consume_data {
@@ -111,7 +149,7 @@ sub _consume_data {
     my $list_len    = scalar( @{$fields_ref} );
     my $server_name = $fields_ref->[0];
 
-    my $columns_ref = $self->get_lc_fields();
+    my $columns_ref = $self->get_expected_fields;
 
     if ( @{$fields_ref} ) {
 
@@ -141,6 +179,10 @@ sub _consume_data {
 
 =item *
 
+L<Siebel::Srvrmgr::ListParser::Output::ListServers::Server>
+
+=item *
+
 L<Siebel::Srvrmgr::ListParser::Output::Tabular>
 
 =item *
